@@ -1,9 +1,12 @@
+# -*- encoding: utf-8 -*-
 from __future__ import absolute_import
 
 from django.core.exceptions import ImproperlyConfigured
 
 from django_hosts.middleware import HostsMiddleware
-from django_hosts.tests.base import override_settings, HostsTestCase, RequestFactory
+from django_hosts.tests.base import (override_settings, HostsTestCase,
+                                     RequestFactory)
+
 
 class MiddlewareTests(HostsTestCase):
 
@@ -33,3 +36,13 @@ class MiddlewareTests(HostsTestCase):
         middleware = HostsMiddleware()
         middleware.process_request(request)
         self.assertEqual(request.urlconf, 'django_hosts.tests.urls.simple')
+
+    @override_settings(
+        ROOT_HOSTCONF='django_hosts.tests.hosts.simple',
+        DEFAULT_HOST='with_view_kwargs')
+    def test_fallback_to_defaulthost(self):
+        rf = RequestFactory(HTTP_HOST=u'ß.example.com')
+        request = rf.get('/template/test/')
+        middleware = HostsMiddleware()
+        middleware.process_request(request)
+        self.assertEqual(request.urlconf, 'django_hosts.tests.urls.complex')
